@@ -1,8 +1,9 @@
 import enum
 from dataclasses import dataclass, field
 
+from .common import Light
 from .object import Decor, Object, Prism
-from .pbdf import PbdfReader, PbdfWriter
+from .pbdf import PbdfReader, PbdfRelease, PbdfWriter
 from .texture import TextureProject
 from .typing import vec2, vec2_new, vec3, vec3_new
 
@@ -93,7 +94,7 @@ class Motor:
         self.steer_max = read.f()
         self.steer_speed = read.f()
         self.steer_recall = read.f()
-        read.bytes(4)
+        read.bytes(8 if read.format.release == PbdfRelease.OEM else 4)
         self.unknown494 = read.f()
         read.bytes(112)
         self.inertia_moments = read.vec3()
@@ -121,7 +122,7 @@ class Motor:
         write.f(self.steer_max)
         write.f(self.steer_speed)
         write.f(self.steer_recall)
-        write.bytes(bytearray(4))
+        write.bytes(bytearray(8 if write.format.release == PbdfRelease.OEM else 4))
         write.f(self.unknown494)
         write.bytes(bytearray(112))
         write.vec3(self.inertia_moments)
@@ -150,7 +151,7 @@ class Auto:
     wheel_rl: AutoPart = field(default_factory=AutoPart)
     chassis: AutoPart = field(default_factory=AutoPart)
     motor: Motor = field(default_factory=Motor)
-    motor_curves: list[int] = field(default_factory=list)
+    motor_curves: list[int] = field(default_factory=list[int])
 
     def read(self, read: PbdfReader) -> None:
         self.wheel_fr = read.any(AutoPart)
@@ -217,6 +218,7 @@ class Graphics:
     shadow_f0: Object = field(default_factory=Object)
     shadow_r2: Object = field(default_factory=Object)
     shadow_f2: Object = field(default_factory=Object)
+    shadow_oem: Object = field(default_factory=Object)
 
     def read(self, read: PbdfReader) -> None:
         self.texture_project_name = read.str()
@@ -244,10 +246,13 @@ class Graphics:
         self.wheel_rr = read.any(GraphicsObject, self.has_face_material)
         self.wheel_fl = read.any(GraphicsObject, self.has_face_material)
         self.wheel_rl = read.any(GraphicsObject, self.has_face_material)
-        self.shadow_r0 = read.any(Object, self.has_face_material, False, True)
-        self.shadow_f0 = read.any(Object, self.has_face_material, False, True)
-        self.shadow_r2 = read.any(Object, self.has_face_material, False, True)
-        self.shadow_f2 = read.any(Object, self.has_face_material, False, True)
+        if read.format.release == PbdfRelease.OEM:
+            self.shadow_oem = read.any(Object, self.has_face_material, False, True)
+        else:
+            self.shadow_r0 = read.any(Object, self.has_face_material, False, True)
+            self.shadow_f0 = read.any(Object, self.has_face_material, False, True)
+            self.shadow_r2 = read.any(Object, self.has_face_material, False, True)
+            self.shadow_f2 = read.any(Object, self.has_face_material, False, True)
 
     def write(self, write: PbdfWriter) -> None:
         write.str(self.texture_project_name)
@@ -275,10 +280,13 @@ class Graphics:
         write.any(self.wheel_rr, self.has_face_material)
         write.any(self.wheel_fl, self.has_face_material)
         write.any(self.wheel_rl, self.has_face_material)
-        write.any(self.shadow_r0, self.has_face_material, False, True)
-        write.any(self.shadow_f0, self.has_face_material, False, True)
-        write.any(self.shadow_r2, self.has_face_material, False, True)
-        write.any(self.shadow_f2, self.has_face_material, False, True)
+        if write.format.release == PbdfRelease.OEM:
+            write.any(self.shadow_oem, self.has_face_material, False, True)
+        else:
+            write.any(self.shadow_r0, self.has_face_material, False, True)
+            write.any(self.shadow_f0, self.has_face_material, False, True)
+            write.any(self.shadow_r2, self.has_face_material, False, True)
+            write.any(self.shadow_f2, self.has_face_material, False, True)
 
 
 @dataclass
@@ -343,14 +351,17 @@ class Vehicle:
     name: str = ""
     auto: Auto = field(default_factory=Auto)
     graphics: Graphics = field(default_factory=Graphics)
-    lod1: Decor = field(default_factory=Decor)
-    lod2: Decor = field(default_factory=Decor)
+    lod1_file_name: str = ""
+    lod1_file: Decor = field(default_factory=Decor)
+    lod2_file_name: str = ""
+    lod2_file: Decor = field(default_factory=Decor)
     sounds: Sounds = field(default_factory=Sounds)
     default_accel: int = 0
     default_brakes: int = 0
     default_grip: int = 0
     default_handling: int = 0
     default_speed: int = 0
+    light: Light = field(default_factory=Light)
 
     def read(self, read: PbdfReader) -> None:
         read.offset(0)
@@ -358,13 +369,12 @@ class Vehicle:
             self.name = read.str()
         if read.format.version < 8:
             self.auto = read.any(Auto)
-            self.graphics = read.any(Graphics)
-            self.lod1 = read.any(Decor)
-            self.lod2 = read.any(Decor)
-        else:
-            self.graphics = read.any(Graphics)
-            self.lod1 = read.any(Decor)
-            self.lod2 = read.any(Decor)
+        self.graphics = read.any(Graphics)
+        self.lod1_file_name = read.str()
+        self.lod1_file = read.any(Decor)
+        self.lod2_file_name = read.str()
+        self.lod2_file = read.any(Decor)
+        if read.format.version >= 8:
             self.auto = read.any(Auto)
         self.sounds = read.any(Sounds)
         if read.format.version < 8:
@@ -384,7 +394,7 @@ class Vehicle:
             self.default_speed = read.i32()
             self.default_grip = read.i32()
             self.default_accel = read.i32()
-        read.bytes(32)
+        self.light = read.any(Light)
         if read.format.version > 5:
             self.name = read.str()
 
@@ -394,13 +404,12 @@ class Vehicle:
             write.str(self.name)
         if write.format.version < 8:
             write.any(self.auto)
-            write.any(self.graphics)
-            write.any(self.lod1)
-            write.any(self.lod2)
-        else:
-            write.any(self.graphics)
-            write.any(self.lod1)
-            write.any(self.lod2)
+        write.any(self.graphics)
+        write.str(self.lod1_file_name)
+        write.any(self.lod1_file)
+        write.str(self.lod2_file_name)
+        write.any(self.lod2_file)
+        if write.format.version >= 8:
             write.any(self.auto)
         write.any(self.sounds)
         if write.format.version < 8:
@@ -420,6 +429,6 @@ class Vehicle:
             write.i32(self.default_speed)
             write.i32(self.default_grip)
             write.i32(self.default_accel)
-        write.bytes(bytearray(32))
+        write.any(self.light)
         if write.format.version > 5:
             write.str(self.name)
